# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/event_provider_api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!exchange/event_provider_api.proto\x12\x12\x65vent_provider_api\"\x18\n\x16GetLatestHeightRequest\"o\n\x17GetLatestHeightResponse\x12\t\n\x01v\x18\x01 \x01(\t\x12\t\n\x01s\x18\x02 \x01(\t\x12\t\n\x01\x65\x18\x03 \x01(\t\x12\x33\n\x04\x64\x61ta\x18\x04 \x01(\x0b\x32%.event_provider_api.LatestBlockHeight\"#\n\x11LatestBlockHeight\x12\x0e\n\x06height\x18\x01 \x01(\x04\";\n\x18StreamBlockEventsRequest\x12\x0f\n\x07\x62\x61\x63kend\x18\x01 \x01(\t\x12\x0e\n\x06height\x18\x02 \x01(\x11\"F\n\x19StreamBlockEventsResponse\x12)\n\x06\x62locks\x18\x01 \x03(\x0b\x32\x19.event_provider_api.Block\"i\n\x05\x42lock\x12\x0e\n\x06height\x18\x01 \x01(\x12\x12\x0f\n\x07version\x18\x02 \x01(\t\x12.\n\x06\x65vents\x18\x03 \x03(\x0b\x32\x1e.event_provider_api.BlockEvent\x12\x0f\n\x07in_sync\x18\x04 \x01(\x08\">\n\nBlockEvent\x12\x10\n\x08type_url\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c\x12\x0f\n\x07tx_hash\x18\x03 \x01(\x0c\";\n\x18GetBlockEventsRPCRequest\x12\x0f\n\x07\x62\x61\x63kend\x18\x01 \x01(\t\x12\x0e\n\x06height\x18\x02 \x01(\x11\"n\n\x19GetBlockEventsRPCResponse\x12\t\n\x01v\x18\x01 \x01(\t\x12\t\n\x01s\x18\x02 \x01(\t\x12\t\n\x01\x65\x18\x03 \x01(\t\x12\x30\n\x04\x64\x61ta\x18\x04 \x01(\x0b\x32\".event_provider_api.BlockEventsRPC\"\xa5\x01\n\x0e\x42lockEventsRPC\x12\r\n\x05types\x18\x01 \x03(\t\x12\x0e\n\x06\x65vents\x18\x02 \x03(\x0c\x12\x43\n\ttx_hashes\x18\x03 \x03(\x0b\x32\x30.event_provider_api.BlockEventsRPC.TxHashesEntry\x1a/\n\rTxHashesEntry\x12\x0b\n\x03key\x18\x01 \x01(\x11\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"L\n\x19GetCustomEventsRPCRequest\x12\x0f\n\x07\x62\x61\x63kend\x18\x01 \x01(\t\x12\x0e\n\x06height\x18\x02 \x01(\x11\x12\x0e\n\x06\x65vents\x18\x03 \x01(\t\"o\n\x1aGetCustomEventsRPCResponse\x12\t\n\x01v\x18\x01 \x01(\t\x12\t\n\x01s\x18\x02 \x01(\t\x12\t\n\x01\x65\x18\x03 \x01(\t\x12\x30\n\x04\x64\x61ta\x18\x04 \x01(\x0b\x32\".event_provider_api.BlockEventsRPC2\xd9\x03\n\x10\x45ventProviderAPI\x12j\n\x0fGetLatestHeight\x12*.event_provider_api.GetLatestHeightRequest\x1a+.event_provider_api.GetLatestHeightResponse\x12r\n\x11StreamBlockEvents\x12,.event_provider_api.StreamBlockEventsRequest\x1a-.event_provider_api.StreamBlockEventsResponse0\x01\x12p\n\x11GetBlockEventsRPC\x12,.event_provider_api.GetBlockEventsRPCRequest\x1a-.event_provider_api.GetBlockEventsRPCResponse\x12s\n\x12GetCustomEventsRPC\x12-.event_provider_api.GetCustomEventsRPCRequest\x1a..event_provider_api.GetCustomEventsRPCResponseB\x17Z\x15/event_provider_apipbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exchange.event_provider_api_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\025/event_provider_apipb'
  _BLOCKEVENTSRPC_TXHASHESENTRY._options = None
  _BLOCKEVENTSRPC_TXHASHESENTRY._serialized_options = b'8\001'
  _globals['_GETLATESTHEIGHTREQUEST']._serialized_start=57
  _globals['_GETLATESTHEIGHTREQUEST']._serialized_end=81
  _globals['_GETLATESTHEIGHTRESPONSE']._serialized_start=83
  _globals['_GETLATESTHEIGHTRESPONSE']._serialized_end=194
  _globals['_LATESTBLOCKHEIGHT']._serialized_start=196
  _globals['_LATESTBLOCKHEIGHT']._serialized_end=231
  _globals['_STREAMBLOCKEVENTSREQUEST']._serialized_start=233
  _globals['_STREAMBLOCKEVENTSREQUEST']._serialized_end=292
  _globals['_STREAMBLOCKEVENTSRESPONSE']._serialized_start=294
  _globals['_STREAMBLOCKEVENTSRESPONSE']._serialized_end=364
  _globals['_BLOCK']._serialized_start=366
  _globals['_BLOCK']._serialized_end=471
  _globals['_BLOCKEVENT']._serialized_start=473
  _globals['_BLOCKEVENT']._serialized_end=535
  _globals['_GETBLOCKEVENTSRPCREQUEST']._serialized_start=537
  _globals['_GETBLOCKEVENTSRPCREQUEST']._serialized_end=596
  _globals['_GETBLOCKEVENTSRPCRESPONSE']._serialized_start=598
  _globals['_GETBLOCKEVENTSRPCRESPONSE']._serialized_end=708
  _globals['_BLOCKEVENTSRPC']._serialized_start=711
  _globals['_BLOCKEVENTSRPC']._serialized_end=876
  _globals['_BLOCKEVENTSRPC_TXHASHESENTRY']._serialized_start=829
  _globals['_BLOCKEVENTSRPC_TXHASHESENTRY']._serialized_end=876
  _globals['_GETCUSTOMEVENTSRPCREQUEST']._serialized_start=878
  _globals['_GETCUSTOMEVENTSRPCREQUEST']._serialized_end=954
  _globals['_GETCUSTOMEVENTSRPCRESPONSE']._serialized_start=956
  _globals['_GETCUSTOMEVENTSRPCRESPONSE']._serialized_end=1067
  _globals['_EVENTPROVIDERAPI']._serialized_start=1070
  _globals['_EVENTPROVIDERAPI']._serialized_end=1543
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/nft/v1beta1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x63osmos/nft/v1beta1/tx.proto\x12\x12\x63osmos.nft.v1beta1\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\"\x8a\x01\n\x07MsgSend\x12\x10\n\x08\x63lass_id\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12(\n\x06sender\x18\x03 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12*\n\x08receiver\x18\x04 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString:\x0b\x82\xe7\xb0*\x06sender\"\x11\n\x0fMsgSendResponse2V\n\x03Msg\x12H\n\x04Send\x12\x1b.cosmos.nft.v1beta1.MsgSend\x1a#.cosmos.nft.v1beta1.MsgSendResponse\x1a\x05\x80\xe7\xb0*\x01\x42$Z\"github.com/cosmos/cosmos-sdk/x/nftb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.nft.v1beta1.tx_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\"github.com/cosmos/cosmos-sdk/x/nft'
  _MSGSEND.fields_by_name['sender']._options = None
  _MSGSEND.fields_by_name['sender']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGSEND.fields_by_name['receiver']._options = None
  _MSGSEND.fields_by_name['receiver']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGSEND._options = None
  _MSGSEND._serialized_options = b'\202\347\260*\006sender'
  _MSG._options = None
  _MSG._serialized_options = b'\200\347\260*\001'
  _globals['_MSGSEND']._serialized_start=104
  _globals['_MSGSEND']._serialized_end=242
  _globals['_MSGSENDRESPONSE']._serialized_start=244
  _globals['_MSGSENDRESPONSE']._serialized_end=261
  _globals['_MSG']._serialized_start=263
  _globals['_MSG']._serialized_end=349
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/interchain_accounts/v1/account.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.auth.v1beta1 import auth_pb2 as cosmos_dot_auth_dot_v1beta1_dot_auth__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5ibc/applications/interchain_accounts/v1/account.proto\x12\'ibc.applications.interchain_accounts.v1\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/auth/v1beta1/auth.proto\"\xe1\x01\n\x11InterchainAccount\x12S\n\x0c\x62\x61se_account\x18\x01 \x01(\x0b\x32 .cosmos.auth.v1beta1.BaseAccountB\x1b\xd0\xde\x1f\x01\xf2\xde\x1f\x13yaml:\"base_account\"\x12/\n\raccount_owner\x18\x02 \x01(\tB\x18\xf2\xde\x1f\x14yaml:\"account_owner\":F\x88\xa0\x1f\x00\x98\xa0\x1f\x00\xca\xb4-:ibc.applications.interchain_accounts.v1.InterchainAccountIBGZEgithub.com/cosmos/ibc-go/v7/modules/apps/27-interchain-accounts/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.interchain_accounts.v1.account_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZEgithub.com/cosmos/ibc-go/v7/modules/apps/27-interchain-accounts/types'
  _INTERCHAINACCOUNT.fields_by_name['base_account']._options = None
  _INTERCHAINACCOUNT.fields_by_name['base_account']._serialized_options = b'\320\336\037\001\362\336\037\023yaml:\"base_account\"'
  _INTERCHAINACCOUNT.fields_by_name['account_owner']._options = None
  _INTERCHAINACCOUNT.fields_by_name['account_owner']._serialized_options = b'\362\336\037\024yaml:\"account_owner\"'
  _INTERCHAINACCOUNT._options = None
  _INTERCHAINACCOUNT._serialized_options = b'\210\240\037\000\230\240\037\000\312\264-:ibc.applications.interchain_accounts.v1.InterchainAccountI'
  _globals['_INTERCHAINACCOUNT']._serialized_start=180
  _globals['_INTERCHAINACCOUNT']._serialized_end=405
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/oracle/v1beta1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from injective.oracle.v1beta1 import oracle_pb2 as injective_dot_oracle_dot_v1beta1_dot_oracle__pb2
from cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!injective/oracle/v1beta1/tx.proto\x12\x18injective.oracle.v1beta1\x1a\x14gogoproto/gogo.proto\x1a%injective/oracle/v1beta1/oracle.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x19\x63osmos_proto/cosmos.proto\"\xa0\x01\n\x16MsgRelayProviderPrices\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x10\n\x08provider\x18\x02 \x01(\t\x12\x0f\n\x07symbols\x18\x03 \x03(\t\x12>\n\x06prices\x18\x04 \x03(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec:\x13\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\" \n\x1eMsgRelayProviderPricesResponse\"\x99\x01\n\x16MsgRelayPriceFeedPrice\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x0c\n\x04\x62\x61se\x18\x02 \x03(\t\x12\r\n\x05quote\x18\x03 \x03(\t\x12=\n\x05price\x18\x04 \x03(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec:\x13\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\" \n\x1eMsgRelayPriceFeedPriceResponse\"}\n\x11MsgRelayBandRates\x12\x0f\n\x07relayer\x18\x01 \x01(\t\x12\x0f\n\x07symbols\x18\x02 \x03(\t\x12\r\n\x05rates\x18\x03 \x03(\x04\x12\x15\n\rresolve_times\x18\x04 \x03(\x04\x12\x12\n\nrequestIDs\x18\x05 \x03(\x04:\x0c\x82\xe7\xb0*\x07relayer\"\x1b\n\x19MsgRelayBandRatesResponse\"e\n\x18MsgRelayCoinbaseMessages\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x10\n\x08messages\x18\x02 \x03(\x0c\x12\x12\n\nsignatures\x18\x03 \x03(\x0c:\x13\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\"\"\n MsgRelayCoinbaseMessagesResponse\"Q\n\x16MsgRequestBandIBCRates\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x12\n\nrequest_id\x18\x02 \x01(\x04:\x13\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\" \n\x1eMsgRequestBandIBCRatesResponse\"\x81\x01\n\x12MsgRelayPythPrices\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x46\n\x12price_attestations\x18\x02 \x03(\x0b\x32*.injective.oracle.v1beta1.PriceAttestation:\x13\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x06sender\"\x1c\n\x1aMsgRelayPythPricesResponse\"\x86\x01\n\x0fMsgUpdateParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x36\n\x06params\x18\x02 \x01(\x0b\x32 .injective.oracle.v1beta1.ParamsB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"\x19\n\x17MsgUpdateParamsResponse2\xf4\x06\n\x03Msg\x12\x81\x01\n\x13RelayProviderPrices\x12\x30.injective.oracle.v1beta1.MsgRelayProviderPrices\x1a\x38.injective.oracle.v1beta1.MsgRelayProviderPricesResponse\x12\x81\x01\n\x13RelayPriceFeedPrice\x12\x30.injective.oracle.v1beta1.MsgRelayPriceFeedPrice\x1a\x38.injective.oracle.v1beta1.MsgRelayPriceFeedPriceResponse\x12r\n\x0eRelayBandRates\x12+.injective.oracle.v1beta1.MsgRelayBandRates\x1a\x33.injective.oracle.v1beta1.MsgRelayBandRatesResponse\x12\x81\x01\n\x13RequestBandIBCRates\x12\x30.injective.oracle.v1beta1.MsgRequestBandIBCRates\x1a\x38.injective.oracle.v1beta1.MsgRequestBandIBCRatesResponse\x12\x87\x01\n\x15RelayCoinbaseMessages\x12\x32.injective.oracle.v1beta1.MsgRelayCoinbaseMessages\x1a:.injective.oracle.v1beta1.MsgRelayCoinbaseMessagesResponse\x12u\n\x0fRelayPythPrices\x12,.injective.oracle.v1beta1.MsgRelayPythPrices\x1a\x34.injective.oracle.v1beta1.MsgRelayPythPricesResponse\x12l\n\x0cUpdateParams\x12).injective.oracle.v1beta1.MsgUpdateParams\x1a\x31.injective.oracle.v1beta1.MsgUpdateParamsResponseBNZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.oracle.v1beta1.tx_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/types'
  _MSGRELAYPROVIDERPRICES.fields_by_name['prices']._options = None
  _MSGRELAYPROVIDERPRICES.fields_by_name['prices']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _MSGRELAYPROVIDERPRICES._options = None
  _MSGRELAYPROVIDERPRICES._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender'
  _MSGRELAYPRICEFEEDPRICE.fields_by_name['price']._options = None
  _MSGRELAYPRICEFEEDPRICE.fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _MSGRELAYPRICEFEEDPRICE._options = None
  _MSGRELAYPRICEFEEDPRICE._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender'
  _MSGRELAYBANDRATES._options = None
  _MSGRELAYBANDRATES._serialized_options = b'\202\347\260*\007relayer'
  _MSGRELAYCOINBASEMESSAGES._options = None
  _MSGRELAYCOINBASEMESSAGES._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender'
  _MSGREQUESTBANDIBCRATES._options = None
  _MSGREQUESTBANDIBCRATES._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender'
  _MSGRELAYPYTHPRICES._options = None
  _MSGRELAYPYTHPRICES._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\006sender'
  _MSGUPDATEPARAMS.fields_by_name['authority']._options = None
  _MSGUPDATEPARAMS.fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _MSGUPDATEPARAMS.fields_by_name['params']._options = None
  _MSGUPDATEPARAMS.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _MSGUPDATEPARAMS._options = None
  _MSGUPDATEPARAMS._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGRELAYPROVIDERPRICES']._serialized_start=177
  _globals['_MSGRELAYPROVIDERPRICES']._serialized_end=337
  _globals['_MSGRELAYPROVIDERPRICESRESPONSE']._serialized_start=339
  _globals['_MSGRELAYPROVIDERPRICESRESPONSE']._serialized_end=371
  _globals['_MSGRELAYPRICEFEEDPRICE']._serialized_start=374
  _globals['_MSGRELAYPRICEFEEDPRICE']._serialized_end=527
  _globals['_MSGRELAYPRICEFEEDPRICERESPONSE']._serialized_start=529
  _globals['_MSGRELAYPRICEFEEDPRICERESPONSE']._serialized_end=561
  _globals['_MSGRELAYBANDRATES']._serialized_start=563
  _globals['_MSGRELAYBANDRATES']._serialized_end=688
  _globals['_MSGRELAYBANDRATESRESPONSE']._serialized_start=690
  _globals['_MSGRELAYBANDRATESRESPONSE']._serialized_end=717
  _globals['_MSGRELAYCOINBASEMESSAGES']._serialized_start=719
  _globals['_MSGRELAYCOINBASEMESSAGES']._serialized_end=820
  _globals['_MSGRELAYCOINBASEMESSAGESRESPONSE']._serialized_start=822
  _globals['_MSGRELAYCOINBASEMESSAGESRESPONSE']._serialized_end=856
  _globals['_MSGREQUESTBANDIBCRATES']._serialized_start=858
  _globals['_MSGREQUESTBANDIBCRATES']._serialized_end=939
  _globals['_MSGREQUESTBANDIBCRATESRESPONSE']._serialized_start=941
  _globals['_MSGREQUESTBANDIBCRATESRESPONSE']._serialized_end=973
  _globals['_MSGRELAYPYTHPRICES']._serialized_start=976
  _globals['_MSGRELAYPYTHPRICES']._serialized_end=1105
  _globals['_MSGRELAYPYTHPRICESRESPONSE']._serialized_start=1107
  _globals['_MSGRELAYPYTHPRICESRESPONSE']._serialized_end=1135
  _globals['_MSGUPDATEPARAMS']._serialized_start=1138
  _globals['_MSGUPDATEPARAMS']._serialized_end=1272
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=1274
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=1299
  _globals['_MSG']._serialized_start=1302
  _globals['_MSG']._serialized_end=2186
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/fee/v1/metadata.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&ibc/applications/fee/v1/metadata.proto\x12\x17ibc.applications.fee.v1\x1a\x14gogoproto/gogo.proto\"d\n\x08Metadata\x12+\n\x0b\x66\x65\x65_version\x18\x01 \x01(\tB\x16\xf2\xde\x1f\x12yaml:\"fee_version\"\x12+\n\x0b\x61pp_version\x18\x02 \x01(\tB\x16\xf2\xde\x1f\x12yaml:\"app_version\"B7Z5github.com/cosmos/ibc-go/v7/modules/apps/29-fee/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.fee.v1.metadata_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/cosmos/ibc-go/v7/modules/apps/29-fee/types'
  _METADATA.fields_by_name['fee_version']._options = None
  _METADATA.fields_by_name['fee_version']._serialized_options = b'\362\336\037\022yaml:\"fee_version\"'
  _METADATA.fields_by_name['app_version']._options = None
  _METADATA.fields_by_name['app_version']._serialized_options = b'\362\336\037\022yaml:\"app_version\"'
  _globals['_METADATA']._serialized_start=89
  _globals['_METADATA']._serialized_end=189
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/mint/v1beta1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.mint.v1beta1 import mint_pb2 as cosmos_dot_mint_dot_v1beta1_dot_mint__pb2
from amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!cosmos/mint/v1beta1/genesis.proto\x12\x13\x63osmos.mint.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/mint/v1beta1/mint.proto\x1a\x11\x61mino/amino.proto\"~\n\x0cGenesisState\x12\x36\n\x06minter\x18\x01 \x01(\x0b\x32\x1b.cosmos.mint.v1beta1.MinterB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12\x36\n\x06params\x18\x02 \x01(\x0b\x32\x1b.cosmos.mint.v1beta1.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x42+Z)github.com/cosmos/cosmos-sdk/x/mint/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.mint.v1beta1.genesis_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z)github.com/cosmos/cosmos-sdk/x/mint/types'
  _GENESISSTATE.fields_by_name['minter']._options = None
  _GENESISSTATE.fields_by_name['minter']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _GENESISSTATE.fields_by_name['params']._options = None
  _GENESISSTATE.fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_GENESISSTATE']._serialized_start=131
  _globals['_GENESISSTATE']._serialized_end=257
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/exchange/v1beta1/proposal.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmos.distribution.v1beta1 import distribution_pb2 as cosmos_dot_distribution_dot_v1beta1_dot_distribution__pb2
from cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from injective.exchange.v1beta1 import exchange_pb2 as injective_dot_exchange_dot_v1beta1_dot_exchange__pb2
from injective.oracle.v1beta1 import oracle_pb2 as injective_dot_oracle_dot_v1beta1_dot_oracle__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)injective/exchange/v1beta1/proposal.proto\x12\x1ainjective.exchange.v1beta1\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a.cosmos/distribution/v1beta1/distribution.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a)injective/exchange/v1beta1/exchange.proto\x1a%injective/oracle/v1beta1/oracle.proto\"\xb5\x04\n\x1dSpotMarketParamUpdateProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x11\n\tmarket_id\x18\x03 \x01(\t\x12\x46\n\x0emaker_fee_rate\x18\x04 \x01(\tB.\xc8\xde\x1f\x01\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x46\n\x0etaker_fee_rate\x18\x05 \x01(\tB.\xc8\xde\x1f\x01\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12N\n\x16relayer_fee_share_rate\x18\x06 \x01(\tB.\xc8\xde\x1f\x01\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12K\n\x13min_price_tick_size\x18\x07 \x01(\tB.\xc8\xde\x1f\x01\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12N\n\x16min_quantity_tick_size\x18\x08 \x01(\tB.\xc8\xde\x1f\x01\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x38\n\x06status\x18\t \x01(\x0e\x32(.injective.exchange.v1beta1.MarketStatus:&\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\"\x86\x01\n\x16\x45xchangeEnableProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12>\n\x0c\x65xchangeType\x18\x03 \x01(\x0e\x32(.injective.exchange.v1beta1.ExchangeType:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xe7\t\n!BatchExchangeModificationProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x65\n\"spot_market_param_update_proposals\x18\x03 \x03(\x0b\x32\x39.injective.exchange.v1beta1.SpotMarketParamUpdateProposal\x12q\n(derivative_market_param_update_proposals\x18\x04 \x03(\x0b\x32?.injective.exchange.v1beta1.DerivativeMarketParamUpdateProposal\x12Z\n\x1cspot_market_launch_proposals\x18\x05 \x03(\x0b\x32\x34.injective.exchange.v1beta1.SpotMarketLaunchProposal\x12\x64\n!perpetual_market_launch_proposals\x18\x06 \x03(\x0b\x32\x39.injective.exchange.v1beta1.PerpetualMarketLaunchProposal\x12m\n&expiry_futures_market_launch_proposals\x18\x07 \x03(\x0b\x32=.injective.exchange.v1beta1.ExpiryFuturesMarketLaunchProposal\x12p\n\'trading_reward_campaign_update_proposal\x18\x08 \x01(\x0b\x32?.injective.exchange.v1beta1.TradingRewardCampaignUpdateProposal\x12m\n&binary_options_market_launch_proposals\x18\t \x03(\x0b\x32=.injective.exchange.v1beta1.BinaryOptionsMarketLaunchProposal\x12q\n%binary_options_param_update_proposals\x18\n \x03(\x0b\x32\x42.injective.exchange.v1beta1.BinaryOptionsMarketParamUpdateProposal\x12_\n\x1e\x64\x65nom_decimals_update_proposal\x18\x0b \x01(\x0b\x32\x37.injective.exchange.v1beta1.UpdateDenomDecimalsProposal\x12N\n\x15\x66\x65\x65_discount_proposal\x18\x0c \x01(\x0b\x32/.injective.exchange.v1beta1.FeeDiscountProposal\x12\x66\n\"market_forced_settlement_proposals\x18\r \x03(\x0b\x32:.injective.exchange.v1beta1.MarketForcedSettlementProposal:&\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\"\xcc\x03\n\x18SpotMarketLaunchProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06ticker\x18\x03 \x01(\t\x12\x12\n\nbase_denom\x18\x04 \x01(\t\x12\x13\n\x0bquote_denom\x18\x05 \x01(\t\x12K\n\x13min_price_tick_size\x18\x06 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12N\n\x16min_quantity_tick_size\x18\x07 \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x46\n\x0emaker_fee_rate\x18\x08 \x01(\tB.\xc8\xde\x1f\x01\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x46\n\x0etaker_fee_rate\x18\t \x01(\tB.\xc8\xde\x1f\x01\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec:&\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\"\xe0\x05\n\x1dPerpetualMarketLaunchProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06ticker\x18\x03 \x01(\t\x12\x13\n\x0bquote_denom\x18\x04 \x01(\t\x12\x13\n\x0boracle_base\x18\x05 \x01(\t\x12\x14\n\x0coracle_quote\x18\x06 \x01(\t\x12\x1b\n\x13oracle_scale_factor\x18\x07 \x01(\r\x12\x39\n\x0boracle_type\x18\x08 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleType\x12L\n\x14initial_margin_ratio\x18\t \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12P\n\x18maintenance_margin_ratio\x18\n \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x46\n\x0emaker_fee_rate\x18\x0b \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x46\n\x0etaker_fee_rate\x18\x0c \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12K\n\x13min_price_tick_size\x18\r \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12N\n\x16min_quantity_tick_size\x18\x0e \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec:&\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\"\x94\x05\n!BinaryOptionsMarketLaunchProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06ticker\x18\x03 \x01(\t\x12\x15\n\roracle_symbol\x18\x04 \x01(\t\x12\x17\n\x0foracle_provider\x18\x05 \x01(\t\x12\x39\n\x0boracle_type\x18\x06 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleType\x12\x1b\n\x13oracle_scale_factor\x18\x07 \x01(\r\x12\x1c\n\x14\x65xpiration_timestamp\x18\x08 \x01(\x03\x12\x1c\n\x14settlement_timestamp\x18\t \x01(\x03\x12\r\n\x05\x61\x64min\x18\n \x01(\t\x12\x13\n\x0bquote_denom\x18\x0b \x01(\t\x12\x46\n\x0emaker_fee_rate\x18\x0c \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x46\n\x0etaker_fee_rate\x18\r \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12K\n\x13min_price_tick_size\x18\x0e \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12N\n\x16min_quantity_tick_size\x18\x0f \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec:&\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\"\xf4\x05\n!ExpiryFuturesMarketLaunchProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06ticker\x18\x03 \x01(\t\x12\x13\n\x0bquote_denom\x18\x04 \x01(\t\x12\x13\n\x0boracle_base\x18\x05 \x01(\t\x12\x14\n\x0coracle_quote\x18\x06 \x01(\t\x12\x1b\n\x13oracle_scale_factor\x18\x07 \x01(\r\x12\x39\n\x0boracle_type\x18\x08 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleType\x12\x0e\n\x06\x65xpiry\x18\t \x01(\x03\x12L\n\x14initial_margin_ratio\x18\n \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12P\n\x18maintenance_margin_ratio\x18\x0b \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x46\n\x0emaker_fee_rate\x18\x0c \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x46\n\x0etaker_fee_rate\x18\r \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12K\n\x13min_price_tick_size\x18\x0e \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12N\n\x16min_quantity_tick_size\x18\x0f \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec:&\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\"\xb6\x07\n#DerivativeMarketParamUpdateProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x11\n\tmarket_id\x18\x03 \x01(\t\x12L\n\x14initial_margin_ratio\x18\x04 \x01(\tB.\xc8\xde\x1f\x01\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12P\n\x18maintenance_margin_ratio\x18\x05 \x01(\tB.\xc8\xde\x1f\x01\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x46\n\x0emaker_fee_rate\x18\x06 \x01(\tB.\xc8\xde\x1f\x01\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x46\n\x0etaker_fee_rate\x18\x07 \x01(\tB.\xc8\xde\x1f\x01\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12N\n\x16relayer_fee_share_rate\x18\x08 \x01(\tB.\xc8\xde\x1f\x01\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12K\n\x13min_price_tick_size\x18\t \x01(\tB.\xc8\xde\x1f\x01\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12N\n\x16min_quantity_tick_size\x18\n \x01(\tB.\xc8\xde\x1f\x01\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12J\n\x12HourlyInterestRate\x18\x0b \x01(\tB.\xc8\xde\x1f\x01\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12L\n\x14HourlyFundingRateCap\x18\x0c \x01(\tB.\xc8\xde\x1f\x01\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x38\n\x06status\x18\r \x01(\x0e\x32(.injective.exchange.v1beta1.MarketStatus\x12?\n\roracle_params\x18\x0e \x01(\x0b\x32(.injective.exchange.v1beta1.OracleParams:&\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\"\xc9\x01\n\x1eMarketForcedSettlementProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x11\n\tmarket_id\x18\x03 \x01(\t\x12H\n\x10settlement_price\x18\x04 \x01(\tB.\xc8\xde\x1f\x01\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec:&\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\"\xac\x01\n\x1bUpdateDenomDecimalsProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x41\n\x0e\x64\x65nom_decimals\x18\x03 \x03(\x0b\x32).injective.exchange.v1beta1.DenomDecimals:&\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\"\x9c\x06\n&BinaryOptionsMarketParamUpdateProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x11\n\tmarket_id\x18\x03 \x01(\t\x12\x46\n\x0emaker_fee_rate\x18\x04 \x01(\tB.\xc8\xde\x1f\x01\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x46\n\x0etaker_fee_rate\x18\x05 \x01(\tB.\xc8\xde\x1f\x01\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12N\n\x16relayer_fee_share_rate\x18\x06 \x01(\tB.\xc8\xde\x1f\x01\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12K\n\x13min_price_tick_size\x18\x07 \x01(\tB.\xc8\xde\x1f\x01\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12N\n\x16min_quantity_tick_size\x18\x08 \x01(\tB.\xc8\xde\x1f\x01\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x1c\n\x14\x65xpiration_timestamp\x18\t \x01(\x03\x12\x1c\n\x14settlement_timestamp\x18\n \x01(\x03\x12H\n\x10settlement_price\x18\x0b \x01(\tB.\xc8\xde\x1f\x01\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\r\n\x05\x61\x64min\x18\x0c \x01(\t\x12\x38\n\x06status\x18\r \x01(\x0e\x32(.injective.exchange.v1beta1.MarketStatus\x12G\n\roracle_params\x18\x0e \x01(\x0b\x32\x30.injective.exchange.v1beta1.ProviderOracleParams:&\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\"\x90\x01\n\x14ProviderOracleParams\x12\x0e\n\x06symbol\x18\x01 \x01(\t\x12\x10\n\x08provider\x18\x02 \x01(\t\x12\x1b\n\x13oracle_scale_factor\x18\x03 \x01(\r\x12\x39\n\x0boracle_type\x18\x04 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleType\"\x91\x01\n\x0cOracleParams\x12\x13\n\x0boracle_base\x18\x01 \x01(\t\x12\x14\n\x0coracle_quote\x18\x02 \x01(\t\x12\x1b\n\x13oracle_scale_factor\x18\x03 \x01(\r\x12\x39\n\x0boracle_type\x18\x04 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleType\"\x8e\x02\n#TradingRewardCampaignLaunchProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12L\n\rcampaign_info\x18\x03 \x01(\x0b\x32\x35.injective.exchange.v1beta1.TradingRewardCampaignInfo\x12M\n\x15\x63\x61mpaign_reward_pools\x18\x04 \x03(\x0b\x32..injective.exchange.v1beta1.CampaignRewardPool:&\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\"\xef\x02\n#TradingRewardCampaignUpdateProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12L\n\rcampaign_info\x18\x03 \x01(\x0b\x32\x35.injective.exchange.v1beta1.TradingRewardCampaignInfo\x12W\n\x1f\x63\x61mpaign_reward_pools_additions\x18\x04 \x03(\x0b\x32..injective.exchange.v1beta1.CampaignRewardPool\x12U\n\x1d\x63\x61mpaign_reward_pools_updates\x18\x05 \x03(\x0b\x32..injective.exchange.v1beta1.CampaignRewardPool:&\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\"p\n\x11RewardPointUpdate\x12\x17\n\x0f\x61\x63\x63ount_address\x18\x01 \x01(\t\x12\x42\n\nnew_points\x18\x0c \x01(\tB.\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\"\xe3\x01\n(TradingRewardPendingPointsUpdateProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x1e\n\x16pending_pool_timestamp\x18\x03 \x01(\x03\x12K\n\x14reward_point_updates\x18\x04 \x03(\x0b\x32-.injective.exchange.v1beta1.RewardPointUpdate:&\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\"\xa4\x01\n\x13\x46\x65\x65\x44iscountProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x41\n\x08schedule\x18\x03 \x01(\x0b\x32/.injective.exchange.v1beta1.FeeDiscountSchedule:&\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\"\xb9\x01\n\x1f\x42\x61tchCommunityPoolSpendProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12J\n\tproposals\x18\x03 \x03(\x0b\x32\x37.cosmos.distribution.v1beta1.CommunityPoolSpendProposal:&\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\"\xcd\x01\n.AtomicMarketOrderFeeMultiplierScheduleProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12O\n\x16market_fee_multipliers\x18\x03 \x03(\x0b\x32/.injective.exchange.v1beta1.MarketFeeMultiplier:&\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content*x\n\x0c\x45xchangeType\x12\x32\n\x14\x45XCHANGE_UNSPECIFIED\x10\x00\x1a\x18\x8a\x9d \x14\x45XCHANGE_UNSPECIFIED\x12\x12\n\x04SPOT\x10\x01\x1a\x08\x8a\x9d \x04SPOT\x12 \n\x0b\x44\x45RIVATIVES\x10\x02\x1a\x0f\x8a\x9d \x0b\x44\x45RIVATIVESBPZNgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.exchange.v1beta1.proposal_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZNgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/types'
  _EXCHANGETYPE.values_by_name["EXCHANGE_UNSPECIFIED"]._options = None
  _EXCHANGETYPE.values_by_name["EXCHANGE_UNSPECIFIED"]._serialized_options = b'\212\235 \024EXCHANGE_UNSPECIFIED'
  _EXCHANGETYPE.values_by_name["SPOT"]._options = None
  _EXCHANGETYPE.values_by_name["SPOT"]._serialized_options = b'\212\235 \004SPOT'
  _EXCHANGETYPE.values_by_name["DERIVATIVES"]._options = None
  _EXCHANGETYPE.values_by_name["DERIVATIVES"]._serialized_options = b'\212\235 \013DERIVATIVES'
  _SPOTMARKETPARAMUPDATEPROPOSAL.fields_by_name['maker_fee_rate']._options = None
  _SPOTMARKETPARAMUPDATEPROPOSAL.fields_by_name['maker_fee_rate']._serialized_options = b'\310\336\037\001\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _SPOTMARKETPARAMUPDATEPROPOSAL.fields_by_name['taker_fee_rate']._options = None
  _SPOTMARKETPARAMUPDATEPROPOSAL.fields_by_name['taker_fee_rate']._serialized_options = b'\310\336\037\001\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _SPOTMARKETPARAMUPDATEPROPOSAL.fields_by_name['relayer_fee_share_rate']._options = None
  _SPOTMARKETPARAMUPDATEPROPOSAL.fields_by_name['relayer_fee_share_rate']._serialized_options = b'\310\336\037\001\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _SPOTMARKETPARAMUPDATEPROPOSAL.fields_by_name['min_price_tick_size']._options = None
  _SPOTMARKETPARAMUPDATEPROPOSAL.fields_by_name['min_price_tick_size']._serialized_options = b'\310\336\037\001\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _SPOTMARKETPARAMUPDATEPROPOSAL.fields_by_name['min_quantity_tick_size']._options = None
  _SPOTMARKETPARAMUPDATEPROPOSAL.fields_by_name['min_quantity_tick_size']._serialized_options = b'\310\336\037\001\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _SPOTMARKETPARAMUPDATEPROPOSAL._options = None
  _SPOTMARKETPARAMUPDATEPROPOSAL._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content'
  _EXCHANGEENABLEPROPOSAL._options = None
  _EXCHANGEENABLEPROPOSAL._serialized_options = b'\210\240\037\000\350\240\037\000'
  _BATCHEXCHANGEMODIFICATIONPROPOSAL._options = None
  _BATCHEXCHANGEMODIFICATIONPROPOSAL._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content'
  _SPOTMARKETLAUNCHPROPOSAL.fields_by_name['min_price_tick_size']._options = None
  _SPOTMARKETLAUNCHPROPOSAL.fields_by_name['min_price_tick_size']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _SPOTMARKETLAUNCHPROPOSAL.fields_by_name['min_quantity_tick_size']._options = None
  _SPOTMARKETLAUNCHPROPOSAL.fields_by_name['min_quantity_tick_size']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _SPOTMARKETLAUNCHPROPOSAL.fields_by_name['maker_fee_rate']._options = None
  _SPOTMARKETLAUNCHPROPOSAL.fields_by_name['maker_fee_rate']._serialized_options = b'\310\336\037\001\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _SPOTMARKETLAUNCHPROPOSAL.fields_by_name['taker_fee_rate']._options = None
  _SPOTMARKETLAUNCHPROPOSAL.fields_by_name['taker_fee_rate']._serialized_options = b'\310\336\037\001\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _SPOTMARKETLAUNCHPROPOSAL._options = None
  _SPOTMARKETLAUNCHPROPOSAL._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content'
  _PERPETUALMARKETLAUNCHPROPOSAL.fields_by_name['initial_margin_ratio']._options = None
  _PERPETUALMARKETLAUNCHPROPOSAL.fields_by_name['initial_margin_ratio']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _PERPETUALMARKETLAUNCHPROPOSAL.fields_by_name['maintenance_margin_ratio']._options = None
  _PERPETUALMARKETLAUNCHPROPOSAL.fields_by_name['maintenance_margin_ratio']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _PERPETUALMARKETLAUNCHPROPOSAL.fields_by_name['maker_fee_rate']._options = None
  _PERPETUALMARKETLAUNCHPROPOSAL.fields_by_name['maker_fee_rate']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _PERPETUALMARKETLAUNCHPROPOSAL.fields_by_name['taker_fee_rate']._options = None
  _PERPETUALMARKETLAUNCHPROPOSAL.fields_by_name['taker_fee_rate']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _PERPETUALMARKETLAUNCHPROPOSAL.fields_by_name['min_price_tick_size']._options = None
  _PERPETUALMARKETLAUNCHPROPOSAL.fields_by_name['min_price_tick_size']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _PERPETUALMARKETLAUNCHPROPOSAL.fields_by_name['min_quantity_tick_size']._options = None
  _PERPETUALMARKETLAUNCHPROPOSAL.fields_by_name['min_quantity_tick_size']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _PERPETUALMARKETLAUNCHPROPOSAL._options = None
  _PERPETUALMARKETLAUNCHPROPOSAL._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content'
  _BINARYOPTIONSMARKETLAUNCHPROPOSAL.fields_by_name['maker_fee_rate']._options = None
  _BINARYOPTIONSMARKETLAUNCHPROPOSAL.fields_by_name['maker_fee_rate']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _BINARYOPTIONSMARKETLAUNCHPROPOSAL.fields_by_name['taker_fee_rate']._options = None
  _BINARYOPTIONSMARKETLAUNCHPROPOSAL.fields_by_name['taker_fee_rate']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _BINARYOPTIONSMARKETLAUNCHPROPOSAL.fields_by_name['min_price_tick_size']._options = None
  _BINARYOPTIONSMARKETLAUNCHPROPOSAL.fields_by_name['min_price_tick_size']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _BINARYOPTIONSMARKETLAUNCHPROPOSAL.fields_by_name['min_quantity_tick_size']._options = None
  _BINARYOPTIONSMARKETLAUNCHPROPOSAL.fields_by_name['min_quantity_tick_size']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _BINARYOPTIONSMARKETLAUNCHPROPOSAL._options = None
  _BINARYOPTIONSMARKETLAUNCHPROPOSAL._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content'
  _EXPIRYFUTURESMARKETLAUNCHPROPOSAL.fields_by_name['initial_margin_ratio']._options = None
  _EXPIRYFUTURESMARKETLAUNCHPROPOSAL.fields_by_name['initial_margin_ratio']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _EXPIRYFUTURESMARKETLAUNCHPROPOSAL.fields_by_name['maintenance_margin_ratio']._options = None
  _EXPIRYFUTURESMARKETLAUNCHPROPOSAL.fields_by_name['maintenance_margin_ratio']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _EXPIRYFUTURESMARKETLAUNCHPROPOSAL.fields_by_name['maker_fee_rate']._options = None
  _EXPIRYFUTURESMARKETLAUNCHPROPOSAL.fields_by_name['maker_fee_rate']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _EXPIRYFUTURESMARKETLAUNCHPROPOSAL.fields_by_name['taker_fee_rate']._options = None
  _EXPIRYFUTURESMARKETLAUNCHPROPOSAL.fields_by_name['taker_fee_rate']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _EXPIRYFUTURESMARKETLAUNCHPROPOSAL.fields_by_name['min_price_tick_size']._options = None
  _EXPIRYFUTURESMARKETLAUNCHPROPOSAL.fields_by_name['min_price_tick_size']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _EXPIRYFUTURESMARKETLAUNCHPROPOSAL.fields_by_name['min_quantity_tick_size']._options = None
  _EXPIRYFUTURESMARKETLAUNCHPROPOSAL.fields_by_name['min_quantity_tick_size']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _EXPIRYFUTURESMARKETLAUNCHPROPOSAL._options = None
  _EXPIRYFUTURESMARKETLAUNCHPROPOSAL._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content'
  _DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['initial_margin_ratio']._options = None
  _DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['initial_margin_ratio']._serialized_options = b'\310\336\037\001\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['maintenance_margin_ratio']._options = None
  _DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['maintenance_margin_ratio']._serialized_options = b'\310\336\037\001\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['maker_fee_rate']._options = None
  _DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['maker_fee_rate']._serialized_options = b'\310\336\037\001\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['taker_fee_rate']._options = None
  _DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['taker_fee_rate']._serialized_options = b'\310\336\037\001\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['relayer_fee_share_rate']._options = None
  _DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['relayer_fee_share_rate']._serialized_options = b'\310\336\037\001\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['min_price_tick_size']._options = None
  _DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['min_price_tick_size']._serialized_options = b'\310\336\037\001\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['min_quantity_tick_size']._options = None
  _DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['min_quantity_tick_size']._serialized_options = b'\310\336\037\001\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['HourlyInterestRate']._options = None
  _DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['HourlyInterestRate']._serialized_options = b'\310\336\037\001\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['HourlyFundingRateCap']._options = None
  _DERIVATIVEMARKETPARAMUPDATEPROPOSAL.fields_by_name['HourlyFundingRateCap']._serialized_options = b'\310\336\037\001\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _DERIVATIVEMARKETPARAMUPDATEPROPOSAL._options = None
  _DERIVATIVEMARKETPARAMUPDATEPROPOSAL._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content'
  _MARKETFORCEDSETTLEMENTPROPOSAL.fields_by_name['settlement_price']._options = None
  _MARKETFORCEDSETTLEMENTPROPOSAL.fields_by_name['settlement_price']._serialized_options = b'\310\336\037\001\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _MARKETFORCEDSETTLEMENTPROPOSAL._options = None
  _MARKETFORCEDSETTLEMENTPROPOSAL._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content'
  _UPDATEDENOMDECIMALSPROPOSAL._options = None
  _UPDATEDENOMDECIMALSPROPOSAL._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content'
  _BINARYOPTIONSMARKETPARAMUPDATEPROPOSAL.fields_by_name['maker_fee_rate']._options = None
  _BINARYOPTIONSMARKETPARAMUPDATEPROPOSAL.fields_by_name['maker_fee_rate']._serialized_options = b'\310\336\037\001\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _BINARYOPTIONSMARKETPARAMUPDATEPROPOSAL.fields_by_name['taker_fee_rate']._options = None
  _BINARYOPTIONSMARKETPARAMUPDATEPROPOSAL.fields_by_name['taker_fee_rate']._serialized_options = b'\310\336\037\001\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _BINARYOPTIONSMARKETPARAMUPDATEPROPOSAL.fields_by_name['relayer_fee_share_rate']._options = None
  _BINARYOPTIONSMARKETPARAMUPDATEPROPOSAL.fields_by_name['relayer_fee_share_rate']._serialized_options = b'\310\336\037\001\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _BINARYOPTIONSMARKETPARAMUPDATEPROPOSAL.fields_by_name['min_price_tick_size']._options = None
  _BINARYOPTIONSMARKETPARAMUPDATEPROPOSAL.fields_by_name['min_price_tick_size']._serialized_options = b'\310\336\037\001\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _BINARYOPTIONSMARKETPARAMUPDATEPROPOSAL.fields_by_name['min_quantity_tick_size']._options = None
  _BINARYOPTIONSMARKETPARAMUPDATEPROPOSAL.fields_by_name['min_quantity_tick_size']._serialized_options = b'\310\336\037\001\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _BINARYOPTIONSMARKETPARAMUPDATEPROPOSAL.fields_by_name['settlement_price']._options = None
  _BINARYOPTIONSMARKETPARAMUPDATEPROPOSAL.fields_by_name['settlement_price']._serialized_options = b'\310\336\037\001\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _BINARYOPTIONSMARKETPARAMUPDATEPROPOSAL._options = None
  _BINARYOPTIONSMARKETPARAMUPDATEPROPOSAL._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content'
  _TRADINGREWARDCAMPAIGNLAUNCHPROPOSAL._options = None
  _TRADINGREWARDCAMPAIGNLAUNCHPROPOSAL._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content'
  _TRADINGREWARDCAMPAIGNUPDATEPROPOSAL._options = None
  _TRADINGREWARDCAMPAIGNUPDATEPROPOSAL._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content'
  _REWARDPOINTUPDATE.fields_by_name['new_points']._options = None
  _REWARDPOINTUPDATE.fields_by_name['new_points']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec'
  _TRADINGREWARDPENDINGPOINTSUPDATEPROPOSAL._options = None
  _TRADINGREWARDPENDINGPOINTSUPDATEPROPOSAL._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content'
  _FEEDISCOUNTPROPOSAL._options = None
  _FEEDISCOUNTPROPOSAL._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content'
  _BATCHCOMMUNITYPOOLSPENDPROPOSAL._options = None
  _BATCHCOMMUNITYPOOLSPENDPROPOSAL._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content'
  _ATOMICMARKETORDERFEEMULTIPLIERSCHEDULEPROPOSAL._options = None
  _ATOMICMARKETORDERFEEMULTIPLIERSCHEDULEPROPOSAL._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content'
  _globals['_EXCHANGETYPE']._serialized_start=8872
  _globals['_EXCHANGETYPE']._serialized_end=8992
  _globals['_SPOTMARKETPARAMUPDATEPROPOSAL']._serialized_start=310
  _globals['_SPOTMARKETPARAMUPDATEPROPOSAL']._serialized_end=875
  _globals['_EXCHANGEENABLEPROPOSAL']._serialized_start=878
  _globals['_EXCHANGEENABLEPROPOSAL']._serialized_end=1012
  _globals['_BATCHEXCHANGEMODIFICATIONPROPOSAL']._serialized_start=1015
  _globals['_BATCHEXCHANGEMODIFICATIONPROPOSAL']._serialized_end=2270
  _globals['_SPOTMARKETLAUNCHPROPOSAL']._serialized_start=2273
  _globals['_SPOTMARKETLAUNCHPROPOSAL']._serialized_end=2733
  _globals['_PERPETUALMARKETLAUNCHPROPOSAL']._serialized_start=2736
  _globals['_PERPETUALMARKETLAUNCHPROPOSAL']._serialized_end=3472
  _globals['_BINARYOPTIONSMARKETLAUNCHPROPOSAL']._serialized_start=3475
  _globals['_BINARYOPTIONSMARKETLAUNCHPROPOSAL']._serialized_end=4135
  _globals['_EXPIRYFUTURESMARKETLAUNCHPROPOSAL']._serialized_start=4138
  _globals['_EXPIRYFUTURESMARKETLAUNCHPROPOSAL']._serialized_end=4894
  _globals['_DERIVATIVEMARKETPARAMUPDATEPROPOSAL']._serialized_start=4897
  _globals['_DERIVATIVEMARKETPARAMUPDATEPROPOSAL']._serialized_end=5847
  _globals['_MARKETFORCEDSETTLEMENTPROPOSAL']._serialized_start=5850
  _globals['_MARKETFORCEDSETTLEMENTPROPOSAL']._serialized_end=6051
  _globals['_UPDATEDENOMDECIMALSPROPOSAL']._serialized_start=6054
  _globals['_UPDATEDENOMDECIMALSPROPOSAL']._serialized_end=6226
  _globals['_BINARYOPTIONSMARKETPARAMUPDATEPROPOSAL']._serialized_start=6229
  _globals['_BINARYOPTIONSMARKETPARAMUPDATEPROPOSAL']._serialized_end=7025
  _globals['_PROVIDERORACLEPARAMS']._serialized_start=7028
  _globals['_PROVIDERORACLEPARAMS']._serialized_end=7172
  _globals['_ORACLEPARAMS']._serialized_start=7175
  _globals['_ORACLEPARAMS']._serialized_end=7320
  _globals['_TRADINGREWARDCAMPAIGNLAUNCHPROPOSAL']._serialized_start=7323
  _globals['_TRADINGREWARDCAMPAIGNLAUNCHPROPOSAL']._serialized_end=7593
  _globals['_TRADINGREWARDCAMPAIGNUPDATEPROPOSAL']._serialized_start=7596
  _globals['_TRADINGREWARDCAMPAIGNUPDATEPROPOSAL']._serialized_end=7963
  _globals['_REWARDPOINTUPDATE']._serialized_start=7965
  _globals['_REWARDPOINTUPDATE']._serialized_end=8077
  _globals['_TRADINGREWARDPENDINGPOINTSUPDATEPROPOSAL']._serialized_start=8080
  _globals['_TRADINGREWARDPENDINGPOINTSUPDATEPROPOSAL']._serialized_end=8307
  _globals['_FEEDISCOUNTPROPOSAL']._serialized_start=8310
  _globals['_FEEDISCOUNTPROPOSAL']._serialized_end=8474
  _globals['_BATCHCOMMUNITYPOOLSPENDPROPOSAL']._serialized_start=8477
  _globals['_BATCHCOMMUNITYPOOLSPENDPROPOSAL']._serialized_end=8662
  _globals['_ATOMICMARKETORDERFEEMULTIPLIERSCHEDULEPROPOSAL']._serialized_start=8665
  _globals['_ATOMICMARKETORDERFEEMULTIPLIERSCHEDULEPROPOSAL']._serialized_end=8870
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/fee/v1/fee.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ibc.core.channel.v1 import channel_pb2 as ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!ibc/applications/fee/v1/fee.proto\x12\x17ibc.applications.fee.v1\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x14gogoproto/gogo.proto\x1a!ibc/core/channel/v1/channel.proto\"\xdf\x02\n\x03\x46\x65\x65\x12p\n\x08recv_fee\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBC\xc8\xde\x1f\x00\xf2\xde\x1f\x0fyaml:\"recv_fee\"\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12n\n\x07\x61\x63k_fee\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBB\xc8\xde\x1f\x00\xf2\xde\x1f\x0eyaml:\"ack_fee\"\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12v\n\x0btimeout_fee\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBF\xc8\xde\x1f\x00\xf2\xde\x1f\x12yaml:\"timeout_fee\"\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\"\x81\x01\n\tPacketFee\x12/\n\x03\x66\x65\x65\x18\x01 \x01(\x0b\x32\x1c.ibc.applications.fee.v1.FeeB\x04\xc8\xde\x1f\x00\x12\x31\n\x0erefund_address\x18\x02 \x01(\tB\x19\xf2\xde\x1f\x15yaml:\"refund_address\"\x12\x10\n\x08relayers\x18\x03 \x03(\t\"a\n\nPacketFees\x12S\n\x0bpacket_fees\x18\x01 \x03(\x0b\x32\".ibc.applications.fee.v1.PacketFeeB\x1a\xc8\xde\x1f\x00\xf2\xde\x1f\x12yaml:\"packet_fees\"\"\xb7\x01\n\x14IdentifiedPacketFees\x12J\n\tpacket_id\x18\x01 \x01(\x0b\x32\x1d.ibc.core.channel.v1.PacketIdB\x18\xc8\xde\x1f\x00\xf2\xde\x1f\x10yaml:\"packet_id\"\x12S\n\x0bpacket_fees\x18\x02 \x03(\x0b\x32\".ibc.applications.fee.v1.PacketFeeB\x1a\xc8\xde\x1f\x00\xf2\xde\x1f\x12yaml:\"packet_fees\"B7Z5github.com/cosmos/ibc-go/v7/modules/apps/29-fee/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.fee.v1.fee_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/cosmos/ibc-go/v7/modules/apps/29-fee/types'
  _FEE.fields_by_name['recv_fee']._options = None
  _FEE.fields_by_name['recv_fee']._serialized_options = b'\310\336\037\000\362\336\037\017yaml:\"recv_fee\"\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _FEE.fields_by_name['ack_fee']._options = None
  _FEE.fields_by_name['ack_fee']._serialized_options = b'\310\336\037\000\362\336\037\016yaml:\"ack_fee\"\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _FEE.fields_by_name['timeout_fee']._options = None
  _FEE.fields_by_name['timeout_fee']._serialized_options = b'\310\336\037\000\362\336\037\022yaml:\"timeout_fee\"\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _PACKETFEE.fields_by_name['fee']._options = None
  _PACKETFEE.fields_by_name['fee']._serialized_options = b'\310\336\037\000'
  _PACKETFEE.fields_by_name['refund_address']._options = None
  _PACKETFEE.fields_by_name['refund_address']._serialized_options = b'\362\336\037\025yaml:\"refund_address\"'
  _PACKETFEES.fields_by_name['packet_fees']._options = None
  _PACKETFEES.fields_by_name['packet_fees']._serialized_options = b'\310\336\037\000\362\336\037\022yaml:\"packet_fees\"'
  _IDENTIFIEDPACKETFEES.fields_by_name['packet_id']._options = None
  _IDENTIFIEDPACKETFEES.fields_by_name['packet_id']._serialized_options = b'\310\336\037\000\362\336\037\020yaml:\"packet_id\"'
  _IDENTIFIEDPACKETFEES.fields_by_name['packet_fees']._options = None
  _IDENTIFIEDPACKETFEES.fields_by_name['packet_fees']._serialized_options = b'\310\336\037\000\362\336\037\022yaml:\"packet_fees\"'
  _globals['_FEE']._serialized_start=152
  _globals['_FEE']._serialized_end=503
  _globals['_PACKETFEE']._serialized_start=506
  _globals['_PACKETFEE']._serialized_end=635
  _globals['_PACKETFEES']._serialized_start=637
  _globals['_PACKETFEES']._serialized_end=734
  _globals['_IDENTIFIEDPACKETFEES']._serialized_start=737
  _globals['_IDENTIFIEDPACKETFEES']._serialized_end=920
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/insurance/v1beta1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from injective.insurance.v1beta1 import insurance_pb2 as injective_dot_insurance_dot_v1beta1_dot_insurance__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from injective.insurance.v1beta1 import genesis_pb2 as injective_dot_insurance_dot_v1beta1_dot_genesis__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'injective/insurance/v1beta1/query.proto\x12\x1binjective.insurance.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a+injective/insurance/v1beta1/insurance.proto\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a)injective/insurance/v1beta1/genesis.proto\"\x1d\n\x1bQueryInsuranceParamsRequest\"Y\n\x1cQueryInsuranceParamsResponse\x12\x39\n\x06params\x18\x01 \x01(\x0b\x32#.injective.insurance.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\".\n\x19QueryInsuranceFundRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\"V\n\x1aQueryInsuranceFundResponse\x12\x38\n\x04\x66und\x18\x01 \x01(\x0b\x32*.injective.insurance.v1beta1.InsuranceFund\"\x1c\n\x1aQueryInsuranceFundsRequest\"^\n\x1bQueryInsuranceFundsResponse\x12?\n\x05\x66unds\x18\x01 \x03(\x0b\x32*.injective.insurance.v1beta1.InsuranceFundB\x04\xc8\xde\x1f\x00\"E\n QueryEstimatedRedemptionsRequest\x12\x10\n\x08marketId\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\"T\n!QueryEstimatedRedemptionsResponse\x12/\n\x06\x61mount\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"C\n\x1eQueryPendingRedemptionsRequest\x12\x10\n\x08marketId\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\"R\n\x1fQueryPendingRedemptionsResponse\x12/\n\x06\x61mount\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"\x19\n\x17QueryModuleStateRequest\"T\n\x18QueryModuleStateResponse\x12\x38\n\x05state\x18\x01 \x01(\x0b\x32).injective.insurance.v1beta1.GenesisState2\x96\t\n\x05Query\x12\xb3\x01\n\x0fInsuranceParams\x12\x38.injective.insurance.v1beta1.QueryInsuranceParamsRequest\x1a\x39.injective.insurance.v1beta1.QueryInsuranceParamsResponse\"+\x82\xd3\xe4\x93\x02%\x12#/injective/insurance/v1beta1/params\x12\xc1\x01\n\rInsuranceFund\x12\x36.injective.insurance.v1beta1.QueryInsuranceFundRequest\x1a\x37.injective.insurance.v1beta1.QueryInsuranceFundResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/injective/insurance/v1beta1/insurance_fund/{market_id}\x12\xb9\x01\n\x0eInsuranceFunds\x12\x37.injective.insurance.v1beta1.QueryInsuranceFundsRequest\x1a\x38.injective.insurance.v1beta1.QueryInsuranceFundsResponse\"4\x82\xd3\xe4\x93\x02.\x12,/injective/insurance/v1beta1/insurance_funds\x12\xd1\x01\n\x14\x45stimatedRedemptions\x12=.injective.insurance.v1beta1.QueryEstimatedRedemptionsRequest\x1a>.injective.insurance.v1beta1.QueryEstimatedRedemptionsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/injective/insurance/v1beta1/estimated_redemptions\x12\xc9\x01\n\x12PendingRedemptions\x12;.injective.insurance.v1beta1.QueryPendingRedemptionsRequest\x1a<.injective.insurance.v1beta1.QueryPendingRedemptionsResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/injective/insurance/v1beta1/pending_redemptions\x12\xb6\x01\n\x14InsuranceModuleState\x12\x34.injective.insurance.v1beta1.QueryModuleStateRequest\x1a\x35.injective.insurance.v1beta1.QueryModuleStateResponse\"1\x82\xd3\xe4\x93\x02+\x12)/injective/insurance/v1beta1/module_stateBQZOgithub.com/InjectiveLabs/injective-core/injective-chain/modules/insurance/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.insurance.v1beta1.query_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZOgithub.com/InjectiveLabs/injective-core/injective-chain/modules/insurance/types'
  _QUERYINSURANCEPARAMSRESPONSE.fields_by_name['params']._options = None
  _QUERYINSURANCEPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _QUERYINSURANCEFUNDSRESPONSE.fields_by_name['funds']._options = None
  _QUERYINSURANCEFUNDSRESPONSE.fields_by_name['funds']._serialized_options = b'\310\336\037\000'
  _QUERYESTIMATEDREDEMPTIONSRESPONSE.fields_by_name['amount']._options = None
  _QUERYESTIMATEDREDEMPTIONSRESPONSE.fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _QUERYPENDINGREDEMPTIONSRESPONSE.fields_by_name['amount']._options = None
  _QUERYPENDINGREDEMPTIONSRESPONSE.fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _QUERY.methods_by_name['InsuranceParams']._options = None
  _QUERY.methods_by_name['InsuranceParams']._serialized_options = b'\202\323\344\223\002%\022#/injective/insurance/v1beta1/params'
  _QUERY.methods_by_name['InsuranceFund']._options = None
  _QUERY.methods_by_name['InsuranceFund']._serialized_options = b'\202\323\344\223\0029\0227/injective/insurance/v1beta1/insurance_fund/{market_id}'
  _QUERY.methods_by_name['InsuranceFunds']._options = None
  _QUERY.methods_by_name['InsuranceFunds']._serialized_options = b'\202\323\344\223\002.\022,/injective/insurance/v1beta1/insurance_funds'
  _QUERY.methods_by_name['EstimatedRedemptions']._options = None
  _QUERY.methods_by_name['EstimatedRedemptions']._serialized_options = b'\202\323\344\223\0024\0222/injective/insurance/v1beta1/estimated_redemptions'
  _QUERY.methods_by_name['PendingRedemptions']._options = None
  _QUERY.methods_by_name['PendingRedemptions']._serialized_options = b'\202\323\344\223\0022\0220/injective/insurance/v1beta1/pending_redemptions'
  _QUERY.methods_by_name['InsuranceModuleState']._options = None
  _QUERY.methods_by_name['InsuranceModuleState']._serialized_options = b'\202\323\344\223\002+\022)/injective/insurance/v1beta1/module_state'
  _globals['_QUERYINSURANCEPARAMSREQUEST']._serialized_start=244
  _globals['_QUERYINSURANCEPARAMSREQUEST']._serialized_end=273
  _globals['_QUERYINSURANCEPARAMSRESPONSE']._serialized_start=275
  _globals['_QUERYINSURANCEPARAMSRESPONSE']._serialized_end=364
  _globals['_QUERYINSURANCEFUNDREQUEST']._serialized_start=366
  _globals['_QUERYINSURANCEFUNDREQUEST']._serialized_end=412
  _globals['_QUERYINSURANCEFUNDRESPONSE']._serialized_start=414
  _globals['_QUERYINSURANCEFUNDRESPONSE']._serialized_end=500
  _globals['_QUERYINSURANCEFUNDSREQUEST']._serialized_start=502
  _globals['_QUERYINSURANCEFUNDSREQUEST']._serialized_end=530
  _globals['_QUERYINSURANCEFUNDSRESPONSE']._serialized_start=532
  _globals['_QUERYINSURANCEFUNDSRESPONSE']._serialized_end=626
  _globals['_QUERYESTIMATEDREDEMPTIONSREQUEST']._serialized_start=628
  _globals['_QUERYESTIMATEDREDEMPTIONSREQUEST']._serialized_end=697
  _globals['_QUERYESTIMATEDREDEMPTIONSRESPONSE']._serialized_start=699
  _globals['_QUERYESTIMATEDREDEMPTIONSRESPONSE']._serialized_end=783
  _globals['_QUERYPENDINGREDEMPTIONSREQUEST']._serialized_start=785
  _globals['_QUERYPENDINGREDEMPTIONSREQUEST']._serialized_end=852
  _globals['_QUERYPENDINGREDEMPTIONSRESPONSE']._serialized_start=854
  _globals['_QUERYPENDINGREDEMPTIONSRESPONSE']._serialized_end=936
  _globals['_QUERYMODULESTATEREQUEST']._serialized_start=938
  _globals['_QUERYMODULESTATEREQUEST']._serialized_end=963
  _globals['_QUERYMODULESTATERESPONSE']._serialized_start=965
  _globals['_QUERYMODULESTATERESPONSE']._serialized_end=1049
  _globals['_QUERY']._serialized_start=1052
  _globals['_QUERY']._serialized_end=2226
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from exchange import injective_insurance_rpc_pb2 as exchange_dot_injective__insurance__rpc__pb2


class InjectiveInsuranceRPCStub(object):
    """InjectiveInsuranceRPC defines gRPC API of Insurance provider.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Funds = channel.unary_unary(
                '/injective_insurance_rpc.InjectiveInsuranceRPC/Funds',
                request_serializer=exchange_dot_injective__insurance__rpc__pb2.FundsRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__insurance__rpc__pb2.FundsResponse.FromString,
                )
        self.Redemptions = channel.unary_unary(
                '/injective_insurance_rpc.InjectiveInsuranceRPC/Redemptions',
                request_serializer=exchange_dot_injective__insurance__rpc__pb2.RedemptionsRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__insurance__rpc__pb2.RedemptionsResponse.FromString,
                )


class InjectiveInsuranceRPCServicer(object):
    """InjectiveInsuranceRPC defines gRPC API of Insurance provider.
    """

    def Funds(self, request, context):
        """Funds lists all insurance funds.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Redemptions(self, request, context):
        """PendingRedemptions lists all pending redemptions according to a filter
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_InjectiveInsuranceRPCServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Funds': grpc.unary_unary_rpc_method_handler(
                    servicer.Funds,
                    request_deserializer=exchange_dot_injective__insurance__rpc__pb2.FundsRequest.FromString,
                    response_serializer=exchange_dot_injective__insurance__rpc__pb2.FundsResponse.SerializeToString,
            ),
            'Redemptions': grpc.unary_unary_rpc_method_handler(
                    servicer.Redemptions,
                    request_deserializer=exchange_dot_injective__insurance__rpc__pb2.RedemptionsRequest.FromString,
                    response_serializer=exchange_dot_injective__insurance__rpc__pb2.RedemptionsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'injective_insurance_rpc.InjectiveInsuranceRPC', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class InjectiveInsuranceRPC(object):
    """InjectiveInsuranceRPC defines gRPC API of Insurance provider.
    """

    @staticmethod
    def Funds(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_insurance_rpc.InjectiveInsuranceRPC/Funds',
            exchange_dot_injective__insurance__rpc__pb2.FundsRequest.SerializeToString,
            exchange_dot_injective__insurance__rpc__pb2.FundsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Redemptions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_insurance_rpc.InjectiveInsuranceRPC/Redemptions',
            exchange_dot_injective__insurance__rpc__pb2.RedemptionsRequest.SerializeToString,
            exchange_dot_injective__insurance__rpc__pb2.RedemptionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/interchain_accounts/controller/v1/controller.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCibc/applications/interchain_accounts/controller/v1/controller.proto\x12\x32ibc.applications.interchain_accounts.controller.v1\x1a\x14gogoproto/gogo.proto\"C\n\x06Params\x12\x39\n\x12\x63ontroller_enabled\x18\x01 \x01(\x08\x42\x1d\xf2\xde\x1f\x19yaml:\"controller_enabled\"BRZPgithub.com/cosmos/ibc-go/v7/modules/apps/27-interchain-accounts/controller/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.interchain_accounts.controller.v1.controller_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZPgithub.com/cosmos/ibc-go/v7/modules/apps/27-interchain-accounts/controller/types'
  _PARAMS.fields_by_name['controller_enabled']._options = None
  _PARAMS.fields_by_name['controller_enabled']._serialized_options = b'\362\336\037\031yaml:\"controller_enabled\"'
  _globals['_PARAMS']._serialized_start=145
  _globals['_PARAMS']._serialized_end=212
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/base/abci/v1beta1/abci.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from tendermint.abci import types_pb2 as tendermint_dot_abci_dot_types__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#cosmos/base/abci/v1beta1/abci.proto\x12\x18\x63osmos.base.abci.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1btendermint/abci/types.proto\x1a\x19google/protobuf/any.proto\"\xe6\x02\n\nTxResponse\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\x1a\n\x06txhash\x18\x02 \x01(\tB\n\xe2\xde\x1f\x06TxHash\x12\x11\n\tcodespace\x18\x03 \x01(\t\x12\x0c\n\x04\x63ode\x18\x04 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x05 \x01(\t\x12\x0f\n\x07raw_log\x18\x06 \x01(\t\x12O\n\x04logs\x18\x07 \x03(\x0b\x32(.cosmos.base.abci.v1beta1.ABCIMessageLogB\x17\xc8\xde\x1f\x00\xaa\xdf\x1f\x0f\x41\x42\x43IMessageLogs\x12\x0c\n\x04info\x18\x08 \x01(\t\x12\x12\n\ngas_wanted\x18\t \x01(\x03\x12\x10\n\x08gas_used\x18\n \x01(\x03\x12 \n\x02tx\x18\x0b \x01(\x0b\x32\x14.google.protobuf.Any\x12\x11\n\ttimestamp\x18\x0c \x01(\t\x12,\n\x06\x65vents\x18\r \x03(\x0b\x32\x16.tendermint.abci.EventB\x04\xc8\xde\x1f\x00:\x04\x88\xa0\x1f\x00\"\x92\x01\n\x0e\x41\x42\x43IMessageLog\x12 \n\tmsg_index\x18\x01 \x01(\rB\r\xea\xde\x1f\tmsg_index\x12\x0b\n\x03log\x18\x02 \x01(\t\x12K\n\x06\x65vents\x18\x03 \x03(\x0b\x32%.cosmos.base.abci.v1beta1.StringEventB\x14\xc8\xde\x1f\x00\xaa\xdf\x1f\x0cStringEvents:\x04\x80\xdc \x01\"`\n\x0bStringEvent\x12\x0c\n\x04type\x18\x01 \x01(\t\x12=\n\nattributes\x18\x02 \x03(\x0b\x32#.cosmos.base.abci.v1beta1.AttributeB\x04\xc8\xde\x1f\x00:\x04\x80\xdc \x01\"\'\n\tAttribute\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"/\n\x07GasInfo\x12\x12\n\ngas_wanted\x18\x01 \x01(\x04\x12\x10\n\x08gas_used\x18\x02 \x01(\x04\"\x88\x01\n\x06Result\x12\x10\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x42\x02\x18\x01\x12\x0b\n\x03log\x18\x02 \x01(\t\x12,\n\x06\x65vents\x18\x03 \x03(\x0b\x32\x16.tendermint.abci.EventB\x04\xc8\xde\x1f\x00\x12+\n\rmsg_responses\x18\x04 \x03(\x0b\x32\x14.google.protobuf.Any:\x04\x88\xa0\x1f\x00\"\x85\x01\n\x12SimulationResponse\x12=\n\x08gas_info\x18\x01 \x01(\x0b\x32!.cosmos.base.abci.v1beta1.GasInfoB\x08\xc8\xde\x1f\x00\xd0\xde\x1f\x01\x12\x30\n\x06result\x18\x02 \x01(\x0b\x32 .cosmos.base.abci.v1beta1.Result\"1\n\x07MsgData\x12\x10\n\x08msg_type\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c:\x06\x18\x01\x80\xdc \x01\"s\n\tTxMsgData\x12\x33\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32!.cosmos.base.abci.v1beta1.MsgDataB\x02\x18\x01\x12+\n\rmsg_responses\x18\x02 \x03(\x0b\x32\x14.google.protobuf.Any:\x04\x80\xdc \x01\"\xa6\x01\n\x0fSearchTxsResult\x12\x13\n\x0btotal_count\x18\x01 \x01(\x04\x12\r\n\x05\x63ount\x18\x02 \x01(\x04\x12\x13\n\x0bpage_number\x18\x03 \x01(\x04\x12\x12\n\npage_total\x18\x04 \x01(\x04\x12\r\n\x05limit\x18\x05 \x01(\x04\x12\x31\n\x03txs\x18\x06 \x03(\x0b\x32$.cosmos.base.abci.v1beta1.TxResponse:\x04\x80\xdc \x01\x42(Z\"github.com/cosmos/cosmos-sdk/types\xd8\xe1\x1e\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.base.abci.v1beta1.abci_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\"github.com/cosmos/cosmos-sdk/types\330\341\036\000'
  _TXRESPONSE.fields_by_name['txhash']._options = None
  _TXRESPONSE.fields_by_name['txhash']._serialized_options = b'\342\336\037\006TxHash'
  _TXRESPONSE.fields_by_name['logs']._options = None
  _TXRESPONSE.fields_by_name['logs']._serialized_options = b'\310\336\037\000\252\337\037\017ABCIMessageLogs'
  _TXRESPONSE.fields_by_name['events']._options = None
  _TXRESPONSE.fields_by_name['events']._serialized_options = b'\310\336\037\000'
  _TXRESPONSE._options = None
  _TXRESPONSE._serialized_options = b'\210\240\037\000'
  _ABCIMESSAGELOG.fields_by_name['msg_index']._options = None
  _ABCIMESSAGELOG.fields_by_name['msg_index']._serialized_options = b'\352\336\037\tmsg_index'
  _ABCIMESSAGELOG.fields_by_name['events']._options = None
  _ABCIMESSAGELOG.fields_by_name['events']._serialized_options = b'\310\336\037\000\252\337\037\014StringEvents'
  _ABCIMESSAGELOG._options = None
  _ABCIMESSAGELOG._serialized_options = b'\200\334 \001'
  _STRINGEVENT.fields_by_name['attributes']._options = None
  _STRINGEVENT.fields_by_name['attributes']._serialized_options = b'\310\336\037\000'
  _STRINGEVENT._options = None
  _STRINGEVENT._serialized_options = b'\200\334 \001'
  _RESULT.fields_by_name['data']._options = None
  _RESULT.fields_by_name['data']._serialized_options = b'\030\001'
  _RESULT.fields_by_name['events']._options = None
  _RESULT.fields_by_name['events']._serialized_options = b'\310\336\037\000'
  _RESULT._options = None
  _RESULT._serialized_options = b'\210\240\037\000'
  _SIMULATIONRESPONSE.fields_by_name['gas_info']._options = None
  _SIMULATIONRESPONSE.fields_by_name['gas_info']._serialized_options = b'\310\336\037\000\320\336\037\001'
  _MSGDATA._options = None
  _MSGDATA._serialized_options = b'\030\001\200\334 \001'
  _TXMSGDATA.fields_by_name['data']._options = None
  _TXMSGDATA.fields_by_name['data']._serialized_options = b'\030\001'
  _TXMSGDATA._options = None
  _TXMSGDATA._serialized_options = b'\200\334 \001'
  _SEARCHTXSRESULT._options = None
  _SEARCHTXSRESULT._serialized_options = b'\200\334 \001'
  _globals['_TXRESPONSE']._serialized_start=144
  _globals['_TXRESPONSE']._serialized_end=502
  _globals['_ABCIMESSAGELOG']._serialized_start=505
  _globals['_ABCIMESSAGELOG']._serialized_end=651
  _globals['_STRINGEVENT']._serialized_start=653
  _globals['_STRINGEVENT']._serialized_end=749
  _globals['_ATTRIBUTE']._serialized_start=751
  _globals['_ATTRIBUTE']._serialized_end=790
  _globals['_GASINFO']._serialized_start=792
  _globals['_GASINFO']._serialized_end=839
  _globals['_RESULT']._serialized_start=842
  _globals['_RESULT']._serialized_end=978
  _globals['_SIMULATIONRESPONSE']._serialized_start=981
  _globals['_SIMULATIONRESPONSE']._serialized_end=1114
  _globals['_MSGDATA']._serialized_start=1116
  _globals['_MSGDATA']._serialized_end=1165
  _globals['_TXMSGDATA']._serialized_start=1167
  _globals['_TXMSGDATA']._serialized_end=1282
  _globals['_SEARCHTXSRESULT']._serialized_start=1285
  _globals['_SEARCHTXSRESULT']._serialized_end=1451
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_campaign_rpc.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%exchange/injective_campaign_rpc.proto\x12\x16injective_campaign_rpc\"n\n\x0eRankingRequest\x12\x13\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x17\n\x0f\x61\x63\x63ount_address\x18\x03 \x01(\t\x12\r\n\x05limit\x18\x04 \x01(\x11\x12\x0c\n\x04skip\x18\x05 \x01(\x04\"\xaa\x01\n\x0fRankingResponse\x12\x32\n\x08\x63\x61mpaign\x18\x01 \x01(\x0b\x32 .injective_campaign_rpc.Campaign\x12\x33\n\x05users\x18\x02 \x03(\x0b\x32$.injective_campaign_rpc.CampaignUser\x12.\n\x06paging\x18\x03 \x01(\x0b\x32\x1e.injective_campaign_rpc.Paging\"\x99\x01\n\x08\x43\x61mpaign\x12\x13\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x13\n\x0btotal_score\x18\x04 \x01(\t\x12\x14\n\x0clast_updated\x18\x05 \x01(\x12\x12\x12\n\nstart_date\x18\x06 \x01(\x12\x12\x10\n\x08\x65nd_date\x18\x07 \x01(\x12\x12\x14\n\x0cis_claimable\x18\x08 \x01(\x08\"\xd3\x01\n\x0c\x43\x61mpaignUser\x12\x13\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x17\n\x0f\x61\x63\x63ount_address\x18\x03 \x01(\t\x12\r\n\x05score\x18\x04 \x01(\t\x12\x18\n\x10\x63ontract_updated\x18\x05 \x01(\x08\x12\x14\n\x0c\x62lock_height\x18\x06 \x01(\x12\x12\x12\n\nblock_time\x18\x07 \x01(\x12\x12\x18\n\x10purchased_amount\x18\x08 \x01(\t\x12\x15\n\rgalxe_updated\x18\t \x01(\x08\"\\\n\x06Paging\x12\r\n\x05total\x18\x01 \x01(\x12\x12\x0c\n\x04\x66rom\x18\x02 \x01(\x11\x12\n\n\x02to\x18\x03 \x01(\x11\x12\x1b\n\x13\x63ount_by_subaccount\x18\x04 \x01(\x12\x12\x0c\n\x04next\x18\x05 \x03(\t2r\n\x14InjectiveCampaignRPC\x12Z\n\x07Ranking\x12&.injective_campaign_rpc.RankingRequest\x1a\'.injective_campaign_rpc.RankingResponseB\x1bZ\x19/injective_campaign_rpcpbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exchange.injective_campaign_rpc_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\031/injective_campaign_rpcpb'
  _globals['_RANKINGREQUEST']._serialized_start=65
  _globals['_RANKINGREQUEST']._serialized_end=175
  _globals['_RANKINGRESPONSE']._serialized_start=178
  _globals['_RANKINGRESPONSE']._serialized_end=348
  _globals['_CAMPAIGN']._serialized_start=351
  _globals['_CAMPAIGN']._serialized_end=504
  _globals['_CAMPAIGNUSER']._serialized_start=507
  _globals['_CAMPAIGNUSER']._serialized_end=718
  _globals['_PAGING']._serialized_start=720
  _globals['_PAGING']._serialized_end=812
  _globals['_INJECTIVECAMPAIGNRPC']._serialized_start=814
  _globals['_INJECTIVECAMPAIGNRPC']._serialized_end=928
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ibc.core.connection.v1 import query_pb2 as ibc_dot_core_dot_connection_dot_v1_dot_query__pb2


class QueryStub(object):
    """Query provides defines the gRPC querier service
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Connection = channel.unary_unary(
                '/ibc.core.connection.v1.Query/Connection',
                request_serializer=ibc_dot_core_dot_connection_dot_v1_dot_query__pb2.QueryConnectionRequest.SerializeToString,
                response_deserializer=ibc_dot_core_dot_connection_dot_v1_dot_query__pb2.QueryConnectionResponse.FromString,
                )
        self.Connections = channel.unary_unary(
                '/ibc.core.connection.v1.Query/Connections',
                request_serializer=ibc_dot_core_dot_connection_dot_v1_dot_query__pb2.QueryConnectionsRequest.SerializeToString,
                response_deserializer=ibc_dot_core_dot_connection_dot_v1_dot_query__pb2.QueryConnectionsResponse.FromString,
                )
        self.ClientConnections = channel.unary_unary(
                '/ibc.core.connection.v1.Query/ClientConnections',
                request_serializer=ibc_dot_core_dot_connection_dot_v1_dot_query__pb2.QueryClientConnectionsRequest.SerializeToString,
                response_deserializer=ibc_dot_core_dot_connection_dot_v1_dot_query__pb2.QueryClientConnectionsResponse.FromString,
                )
        self.ConnectionClientState = channel.unary_unary(
                '/ibc.core.connection.v1.Query/ConnectionClientState',
                request_serializer=ibc_dot_core_dot_connection_dot_v1_dot_query__pb2.QueryConnectionClientStateRequest.SerializeToString,
                response_deserializer=ibc_dot_core_dot_connection_dot_v1_dot_query__pb2.QueryConnectionClientStateResponse.FromString,
                )
        self.ConnectionConsensusState = channel.unary_unary(
                '/ibc.core.connection.v1.Query/ConnectionConsensusState',
                request_serializer=ibc_dot_core_dot_connection_dot_v1_dot_query__pb2.QueryConnectionConsensusStateRequest.SerializeToString,
                response_deserializer=ibc_dot_core_dot_connection_dot_v1_dot_query__pb2.QueryConnectionConsensusStateResponse.FromString,
                )
        self.ConnectionParams = channel.unary_unary(
                '/ibc.core.connection.v1.Query/ConnectionParams',
                request_serializer=ibc_dot_core_dot_connection_dot_v1_dot_query__pb2.QueryConnectionParamsRequest.SerializeToString,
                response_deserializer=ibc_dot_core_dot_connection_dot_v1_dot_query__pb2.QueryConnectionParamsResponse.FromString,
                )


class QueryServicer(object):
    """Query provides defines the gRPC querier service
    """

    def Connection(self, request, context):
        """Connection queries an IBC connection end.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Connections(self, request, context):
        """Connections queries all the IBC connections of a chain.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClientConnections(self, request, context):
        """ClientConnections queries the connection paths associated with a client
        state.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConnectionClientState(self, request, context):
        """ConnectionClientState queries the client state associated with the
        connection.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConnectionConsensusState(self, request, context):
        """ConnectionConsensusState queries the consensus state associated with the
        connection.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConnectionParams(self, request, context):
        """ConnectionParams queries all parameters of the ibc connection submodule.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Connection': grpc.unary_unary_rpc_method_handler(
                    servicer.Connection,
                    request_deserializer=ibc_dot_core_dot_connection_dot_v1_dot_query__pb2.QueryConnectionRequest.FromString,
                    response_serializer=ibc_dot_core_dot_connection_dot_v1_dot_query__pb2.QueryConnectionResponse.SerializeToString,
            ),
            'Connections': grpc.unary_unary_rpc_method_handler(
                    servicer.Connections,
                    request_deserializer=ibc_dot_core_dot_connection_dot_v1_dot_query__pb2.QueryConnectionsRequest.FromString,
                    response_serializer=ibc_dot_core_dot_connection_dot_v1_dot_query__pb2.QueryConnectionsResponse.SerializeToString,
            ),
            'ClientConnections': grpc.unary_unary_rpc_method_handler(
                    servicer.ClientConnections,
                    request_deserializer=ibc_dot_core_dot_connection_dot_v1_dot_query__pb2.QueryClientConnectionsRequest.FromString,
                    response_serializer=ibc_dot_core_dot_connection_dot_v1_dot_query__pb2.QueryClientConnectionsResponse.SerializeToString,
            ),
            'ConnectionClientState': grpc.unary_unary_rpc_method_handler(
                    servicer.ConnectionClientState,
                    request_deserializer=ibc_dot_core_dot_connection_dot_v1_dot_query__pb2.QueryConnectionClientStateRequest.FromString,
                    response_serializer=ibc_dot_core_dot_connection_dot_v1_dot_query__pb2.QueryConnectionClientStateResponse.SerializeToString,
            ),
            'ConnectionConsensusState': grpc.unary_unary_rpc_method_handler(
                    servicer.ConnectionConsensusState,
                    request_deserializer=ibc_dot_core_dot_connection_dot_v1_dot_query__pb2.QueryConnectionConsensusStateRequest.FromString,
                    response_serializer=ibc_dot_core_dot_connection_dot_v1_dot_query__pb2.QueryConnectionConsensusStateResponse.SerializeToString,
            ),
            'ConnectionParams': grpc.unary_unary_rpc_method_handler(
                    servicer.ConnectionParams,
                    request_deserializer=ibc_dot_core_dot_connection_dot_v1_dot_query__pb2.QueryConnectionParamsRequest.FromString,
                    response_serializer=ibc_dot_core_dot_connection_dot_v1_dot_query__pb2.QueryConnectionParamsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ibc.core.connection.v1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query provides defines the gRPC querier service
    """

    @staticmethod
    def Connection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.connection.v1.Query/Connection',
            ibc_dot_core_dot_connection_dot_v1_dot_query__pb2.QueryConnectionRequest.SerializeToString,
            ibc_dot_core_dot_connection_dot_v1_dot_query__pb2.QueryConnectionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Connections(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.connection.v1.Query/Connections',
            ibc_dot_core_dot_connection_dot_v1_dot_query__pb2.QueryConnectionsRequest.SerializeToString,
            ibc_dot_core_dot_connection_dot_v1_dot_query__pb2.QueryConnectionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ClientConnections(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.connection.v1.Query/ClientConnections',
            ibc_dot_core_dot_connection_dot_v1_dot_query__pb2.QueryClientConnectionsRequest.SerializeToString,
            ibc_dot_core_dot_connection_dot_v1_dot_query__pb2.QueryClientConnectionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConnectionClientState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.connection.v1.Query/ConnectionClientState',
            ibc_dot_core_dot_connection_dot_v1_dot_query__pb2.QueryConnectionClientStateRequest.SerializeToString,
            ibc_dot_core_dot_connection_dot_v1_dot_query__pb2.QueryConnectionClientStateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConnectionConsensusState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.connection.v1.Query/ConnectionConsensusState',
            ibc_dot_core_dot_connection_dot_v1_dot_query__pb2.QueryConnectionConsensusStateRequest.SerializeToString,
            ibc_dot_core_dot_connection_dot_v1_dot_query__pb2.QueryConnectionConsensusStateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConnectionParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.connection.v1.Query/ConnectionParams',
            ibc_dot_core_dot_connection_dot_v1_dot_query__pb2.QueryConnectionParamsRequest.SerializeToString,
            ibc_dot_core_dot_connection_dot_v1_dot_query__pb2.QueryConnectionParamsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
